@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef DISCOVERDECLARATIVEPLUGIN_H
-#define DISCOVERDECLARATIVEPLUGIN_H
+#pragma once
 
 #include <QQmlExtensionPlugin>
 
@@ -14,8 +13,5 @@ class DiscoverDeclarativePlugin : public QQmlExtensionPlugin
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 public:
-    void initializeEngine(QQmlEngine *engine, const char *uri) override;
     void registerTypes(const char *uri) override;
 };
-
-#endif
