@@ -3,15 +3,14 @@
  *
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
-#ifndef DUMMYNOTIFIER_H
-#define DUMMYNOTIFIER_H
+#pragma once
 
 #include <BackendNotifierModule.h>
 
 class DummyNotifier : public BackendNotifierModule
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "org.kde.discover.BackendNotifierModule")
+    Q_PLUGIN_METADATA(IID DISCOVER_NOTIFIER_IID)
     Q_INTERFACES(BackendNotifierModule)
 public:
     explicit DummyNotifier(QObject *parent = nullptr);
@@ -33,5 +32,3 @@ public:
         return false;
     }
 };
-
-#endif
